==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QTextureCubeMap.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>A QAbstractTexture with a TargetCubeMap target format</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qtexturecubemap.html">Qt3DRender::QTextureCubeMap</a></code></p>
 */
public class QTextureCubeMap extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureCubeMap.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtexturecubemap.html#QTextureCubeMap">Qt3DRender::QTextureCubeMap::<wbr>QTextureCubeMap(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QTextureCubeMap(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTextureCubeMap instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTextureCubeMap(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTextureCubeMap(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTextureCubeMap instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTextureCubeMap(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureCubeMap() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.7.1-sources.jar: io/qt/qt3d/render/QTextureCubeMap.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>A QAbstractTexture with a TargetCubeMap target format</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qtexturecubemap.html">Qt3DRender::QTextureCubeMap</a></code></p>
 */
public class QTextureCubeMap extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTextureCubeMap.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qtexturecubemap.html#QTextureCubeMap">Qt3DRender::QTextureCubeMap::<wbr/>QTextureCubeMap(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QTextureCubeMap(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTextureCubeMap instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QTextureCubeMap(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QTextureCubeMap(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTextureCubeMap instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTextureCubeMap(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTextureCubeMap() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
